==> auth-2.4.0920-sources.jar: com/zing/zalo/zalosdk/oauth/WebLoginActivity.java <==
package com.zing.zalo.zalosdk.oauth;

import android.content.Context;
import android.content.Intent;
import android.os.Build.VERSION;
import android.os.Bundle;
import android.support.v4.app.FragmentActivity;
import android.support.v4.app.FragmentTransaction;
import android.support.v4.content.ContextCompat;
import android.view.View;
import android.view.View.OnClickListener;
import android.view.Window;
import android.widget.FrameLayout;
import android.widget.ImageView;
import android.widget.TextView;
import com.zing.zalo.zalosdk.R;
import com.zing.zalo.zalosdk.auth.internal.d.a;
import com.zing.zalo.zalosdk.auth.internal.e;
import com.zing.zalo.zalosdk.auth.internal.f;
import com.zing.zalo.zalosdk.common.UtilsCore;
import org.json.JSONException;
import org.json.JSONObject;

public class WebLoginActivity extends FragmentActivity implements OnClickListener, a {
    e a;
    f b;
    FrameLayout c;
    int d;
    TextView e;
    ImageView f;
    boolean g;

    public static Intent a(Context context, boolean registerOnly) {
        Intent intent = new Intent(context, WebLoginActivity.class);
        intent.putExtra("registerOnly", registerOnly);
        return intent;
    }

    protected void onActivityResult(int requestCode, int resultCode, Intent data) {
        super.onActivityResult(requestCode, resultCode, data);
        ZaloSDK.Instance.onActivityResult(this, requestCode, resultCode, data);
    }

    protected void onCreate(Bundle savedInstanceState) {
        super.onCreate(savedInstanceState);
        if (VERSION.SDK_INT >= 21) {
            Window window = getWindow();
            window.clearFlags(67108864);
            window.addFlags(Integer.MIN_VALUE);
            window.setStatusBarColor(ContextCompat.getColor(this, R.color.zing_pressed));
        }
        this.g = getIntent().getBooleanExtra("registerOnly", false);
        setContentView(UtilsCore.getResourceId(this, "zalosdk_activity_zalo_web_login", "layout"));
        this.d = UtilsCore.getResourceId(this, "zalosdk_weblogin_container", "id");
        this.c = (FrameLayout) findViewById(this.d);
        this.e = (TextView) findViewById(UtilsCore.getResourceId(this, "zalosdk_txt_title", "id"));
        this.f = (ImageView) findViewById(UtilsCore.getResourceId(this, "zalosdk_back_control", "id"));
        this.f.setOnClickListener(this);
        if (savedInstanceState != null) {
            return;
        }
        if (this.g) {
            this.b = f.b();
            FragmentTransaction transaction = getSupportFragmentManager().beginTransaction();
            transaction.replace(this.d, this.b, "register-fragment");
            transaction.commit();
            return;
        }
        this.a = e.b();
        FragmentTransaction beginTransaction = getSupportFragmentManager().beginTransaction();
        beginTransaction.replace(this.d, this.a, "login-fragment");
        beginTransaction.commitAllowingStateLoss();
    }

    public void onClick(View v) {
        if (v == this.f) {
            UtilsCore.hideSoftKeyboard(this);
            onBackPressed();
        }
    }

    public void onBackPressed() {
        if (this.f != null && this.f.getVisibility() == 0) {
            super.onBackPressed();
        }
    }

    public void onDestroy() {
        super.onDestroy();
    }

    public final void a(String title) {
        if (this.e != null) {
            this.e.setText(title);
        }
    }

    public final void a() {
        if (this.f != null) {
            this.f.setVisibility(0);
        }
    }

    public final void a(int error, long uid, String oauth, int zprotect, String name, boolean isRegister) {
        Intent data = new Intent();
        data.putExtra("error", error);
        data.putExtra("uid", uid);
        data.putExtra("code", oauth);
        data.putExtra("isRegister", isRegister);
        JSONObject extra = new JSONObject();
        JSONObject extraData = new JSONObject();
        try {
            extraData.put("display_name", name);
            extraData.put("zprotect", zprotect);
            extra.put("data", extraData);
        } catch (JSONException e) {
        }
        data.putExtra("data", extra.toString());
        setResult(-1, data);
        finish();
    }
}

==> auth-2.4.1007-sources.jar: com/zing/zalo/zalosdk/oauth/WebLoginActivity.java <==
package com.zing.zalo.zalosdk.oauth;

import android.content.Context;
import android.content.Intent;
import android.os.Build.VERSION;
import android.os.Bundle;
import android.support.v4.app.FragmentActivity;
import android.support.v4.app.FragmentTransaction;
import android.support.v4.content.ContextCompat;
import android.view.View;
import android.view.View.OnClickListener;
import android.view.Window;
import android.widget.FrameLayout;
import android.widget.ImageView;
import android.widget.TextView;
import com.zing.zalo.zalosdk.R;
import com.zing.zalo.zalosdk.auth.internal.d.a;
import com.zing.zalo.zalosdk.auth.internal.e;
import com.zing.zalo.zalosdk.auth.internal.f;
import com.zing.zalo.zalosdk.core.helper.Utils;
import org.json.JSONException;
import org.json.JSONObject;

public class WebLoginActivity extends FragmentActivity implements OnClickListener, a {
    e a;
    f b;
    FrameLayout c;
    int d;
    TextView e;
    ImageView f;
    boolean g;

    public static Intent a(Context context, boolean registerOnly) {
        Intent intent = new Intent(context, WebLoginActivity.class);
        intent.putExtra("registerOnly", registerOnly);
        return intent;
    }

    protected void onActivityResult(int requestCode, int resultCode, Intent data) {
        super.onActivityResult(requestCode, resultCode, data);
        ZaloSDK.Instance.onActivityResult(this, requestCode, resultCode, data);
    }

    protected void onCreate(Bundle savedInstanceState) {
        super.onCreate(savedInstanceState);
        if (VERSION.SDK_INT >= 21) {
            Window window = getWindow();
            window.clearFlags(67108864);
            window.addFlags(Integer.MIN_VALUE);
            window.setStatusBarColor(ContextCompat.getColor(this, R.color.zing_pressed));
        }
        this.g = getIntent().getBooleanExtra("registerOnly", false);
        setContentView(Utils.getResourceId(this, "zalosdk_activity_zalo_web_login", "layout"));
        this.d = Utils.getResourceId(this, "zalosdk_weblogin_container", "id");
        this.c = (FrameLayout) findViewById(this.d);
        this.e = (TextView) findViewById(Utils.getResourceId(this, "zalosdk_txt_title", "id"));
        this.f = (ImageView) findViewById(Utils.getResourceId(this, "zalosdk_back_control", "id"));
        this.f.setOnClickListener(this);
        if (savedInstanceState != null) {
            return;
        }
        if (this.g) {
            this.b = f.b();
            FragmentTransaction transaction = getSupportFragmentManager().beginTransaction();
            transaction.replace(this.d, this.b, "register-fragment");
            transaction.commit();
            return;
        }
        this.a = e.b();
        FragmentTransaction beginTransaction = getSupportFragmentManager().beginTransaction();
        beginTransaction.replace(this.d, this.a, "login-fragment");
        beginTransaction.commitAllowingStateLoss();
    }

    public void onClick(View v) {
        if (v == this.f) {
            Utils.hideSoftKeyboard(this);
            onBackPressed();
        }
    }

    public void onBackPressed() {
        if (this.f != null && this.f.getVisibility() == 0) {
            super.onBackPressed();
        }
    }

    public void onDestroy() {
        super.onDestroy();
    }

    public final void a(String title) {
        if (this.e != null) {
            this.e.setText(title);
        }
    }

    public final void a() {
        if (this.f != null) {
            this.f.setVisibility(0);
        }
    }

    public final void a(int error, long uid, String oauth, int zprotect, String name, boolean isRegister) {
        Intent data = new Intent();
        data.putExtra("error", error);
        data.putExtra("uid", uid);
        data.putExtra("code", oauth);
        data.putExtra("isRegister", isRegister);
        JSONObject extra = new JSONObject();
        JSONObject extraData = new JSONObject();
        try {
            extraData.put("display_name", name);
            extraData.put("zprotect", zprotect);
            extra.put("data", extraData);
        } catch (JSONException e) {
        }
        data.putExtra("data", extra.toString());
        setResult(-1, data);
        finish();
    }
}
